@@ -7,10 +7,10 @@ $lan = array(
   	'Der Benutzer steht auf der Blacklist, deshalb wurde eine Best&auml;tigungsanfrage verschickt.',
   'If user confirms subscription, they will be removed from the blacklist.' =>
   	'Wenn die Benutzer das Abonnement best&auml;tigen, werden Sie von der Blacklist entfernt.',
-  'YouAreBlacklisted' =>
-  	'Ihre E-Mail-Adresse steht auf unserer Blacklist. Dies bedeutet, dass Sie uns gebeten haben, Ihnen nie mehr irgendwelche Newsletters zu schicken.<br/>
-	Das einzige Mail, das unser System verschicken wird, ist eine Best&auml;tigungsanfrage.
-	Nur wenn Sie den Link in dieser Mail anklicken, werden Sie von unserer Blacklist entfernt und erhalten in Zukunft wieder unsere Newsletters.'
+//  'YouAreBlacklisted' =>
+//  	'Ihre E-Mail-Adresse steht auf unserer Blacklist. Dies bedeutet, dass Sie uns gebeten haben, Ihnen nie mehr irgendwelche Newsletters zu schicken.<br/>
+//	Das einzige Mail, das unser System verschicken wird, ist eine Best&auml;tigungsanfrage.
+//	Nur wenn Sie den Link in dieser Mail anklicken, werden Sie von unserer Blacklist entfernt und erhalten in Zukunft wieder unsere Newsletters.'
 );
 
 ?>
\ No newline at end of file
