@@ -61,6 +61,8 @@ if (!defined('ALLOW_IMPORT')) define('ALLOW_IMPORT',1);
 if (!defined('EMPTY_VALUE_PREFIX')) define('EMPTY_VALUE_PREFIX','--');
 if (!defined('USE_ADMIN_DETAILS_FOR_MESSAGES')) define('USE_ADMIN_DETAILS_FOR_MESSAGES',1);
 if (!defined('SEND_ONE_TESTMAIL')) define('SEND_ONE_TESTMAIL',0);
+if (!defined('USE_SPAM_BLOCK')) define('USE_SPAM_BLOCK',1);
+if (!defined('NOTIFY_SPAM')) define('NOTIFY_SPAM',1);
 
 if (!isset($GLOBALS["export_mimetype"])) $GLOBALS["export_mimetype"] = 'application/csv';
 if (!isset($GLOBALS["admin_auth_module"])) $GLOBALS["admin_auth_module"] = 'phplist_auth.inc';
@@ -234,7 +236,10 @@ function sendMailOriginal ($to,$subject,$message,$header = "",$parameters = "")
         if(@mail($GLOBALS["developer_email"],$subject,$message,$header,$parameters)) {
           return 1;
         } else {
-          return mail($GLOBALS["developer_email"],$subject,$message,$header);
+          # Changed by Bas: Always ok, since the mac/xampp return false while sending and no error in /var/log/mail.log
+          # We are in developermode anyway, and errors are faked by code just above this.
+          mail($GLOBALS["developer_email"],$subject,$message,$header);
+          return 1;
         }
       }
     } else {
@@ -275,6 +280,9 @@ function sendMailPhpMailer ($to,$subject,$message) {
       print "Error: Running CVS version, but developer_email not set";
     }
   }
+  # 0008549: message envelope not passed to php mailer,
+  $mail->Sender = $GLOBALS["message_envelope"]; 
+  
   $mail->build_message(
       array(
         "html_charset" => getConfig("html_charset"),
@@ -668,7 +676,8 @@ function cleanUrl($url,$disallowed_params = array('PHPSESSID')) {
   $query = '';
   foreach ($params as $key => $val) {
     if (!in_array($key,$disallowed_params)) {
-      $query .= $key.'='.$val.'&';
+      //0008980: Link Conversion for Click Tracking. no = will be added if key is empty.
+      $query .= $key . ( $val ? '=' . $val . '&' : '&' );
     }
   }
   $query = substr($query,0,-1);
@@ -691,15 +700,15 @@ function adminName($id) {
   return $req[0] ? $req[0] : "<font color=red>Nobody</font>";
 }
 
-if (!function_exists("dbg")) {
-  function dbg($msg,$logfile = "") {
-    if (!$logfile) return;
-    $fp = @fopen($logfile,"a");
-    $line = "[".date("d M Y, H:i:s")."] ".getenv("REQUEST_URI").'('.$config["stats"]["number_of_queries"].") $msg \n";
-    @fwrite($fp,$line);
-    @fclose($fp);
-  }
-}
+//if (!function_exists("dbg")) {
+//  function dbg($msg,$logfile = "") {
+//    if (!$logfile) return;
+//    $fp = @fopen($logfile,"a");
+//    $line = "[".date("d M Y, H:i:s")."] ".getenv("REQUEST_URI").'('.$config["stats"]["number_of_queries"].") $msg \n";
+//    @fwrite($fp,$line);
+//    @fclose($fp);
+//  }
+//}
 
 function addSubscriberStatistics($item = '',$amount,$list = 0) {
   switch (STATS_INTERVAL) {
