@@ -71,13 +71,16 @@ if (!isset($_GET['tab'])) $_GET['tab'] = '';
 
 if (!$id) {
   $defaulttemplate = getConfig('defaultmessagetemplate');
-  Sql_Query(sprintf('insert into %s (subject,status,entered,sendformat,embargo,repeatuntil,owner,template)
-    values("(no subject)","draft",now(),"text and HTML",now(),now(),%d,%d)',$GLOBALS["tables"]["message"],$_SESSION["logindetails"]["id"],$defaulttemplate));
+  Sql_Query(sprintf('insert into %s (subject,status,entered,sendformat,embargo,repeatuntil,owner,template,tofield,replyto)
+    values("(no subject)","draft",now(),"HTML",now(),now(),%d,%d,"","")',$GLOBALS["tables"]["message"],$_SESSION["logindetails"]["id"],$defaulttemplate));
   $id = Sql_Insert_id();
-  Redirect($_GET["page"]."&id=$id");
-  exit;
-
+  # 0008720: Using -p send from the commandline doesn't seem to work
+  if(!$GLOBALS["commandline"]){
+    Redirect($_GET["page"]."&id=$id");
+    exit;
+  }
 }
+
 if (isset($_GET['deleterule']) && $_GET["deleterule"]) {
   Sql_Query(sprintf('delete from %s where name = "criterion%d" and id = %d',$GLOBALS["tables"]["messagedata"],$_GET["deleterule"],$_GET["id"]));
   Redirect($_GET["page"]."&id=$id&tab=".$_GET["tab"]);
@@ -331,10 +334,13 @@ if ($send || $sendtest || $prepare || $save) {
     #  mark this  message  as listmessage for list  0
     $result  =  Sql_query("insert ignore into $tables[listmessage]  (messageid,listid,entered) values($messageid,0,now())");
   }
-
-  if (isset($_POST["excludelist"]) && is_array($_POST["excludelist"])) {
-    $exclude = join(",",$_POST["excludelist"]);
-    Sql_Query(sprintf('replace into %s (name,id,data) values("excludelist",%d,"%s")',$tables["messagedata"],$messageid,$exclude));
+  if (USE_LIST_EXCLUDE) {
+    if (isset($_POST["excludelist"]) && is_array($_POST["excludelist"])) {
+      $exclude = join(",",$_POST["excludelist"]);
+      Sql_Query(sprintf('replace into %s (name,id,data) values("excludelist",%d,"%s")',$tables["messagedata"],$messageid,$exclude));
+    } else {
+      Sql_Query(sprintf('replace into %s (name,id,data) values("excludelist",%d,"%s")',$tables["messagedata"],$messageid,0));
+    }
   }
 
 # we want to create a join on tables as follows, in order to find users who have their attributes to the values chosen
@@ -669,11 +675,17 @@ for ($i = 1; $i<=$num;$i++) {
     $ls->addColumn('<!--'.$crit_data["attribute"].'-->'.$crit_data["attribute_name"],$GLOBALS['I18N']->get('operator'),$GLOBALS['I18N']->get($crit_data["operator"]));
     $ls->addColumn('<!--'.$crit_data["attribute"].'-->'.$crit_data["attribute_name"],$GLOBALS['I18N']->get('values'),$crit_data["values"]);
     $ls->addColumn('<!--'.$crit_data["attribute"].'-->'.$crit_data["attribute_name"],$GLOBALS['I18N']->get('remove'),PageLink2($delete_base."&amp;deleterule=".$i,$GLOBALS['I18N']->get("remove")));
-    $attribute = $_POST["criteria"][$i];
+    if (isset($_POST["criteria"][$i])) {
+      $attribute = $_POST["criteria"][$i];
+    } else {
+      $attribute = '';
+    }
+    ## fix 6063
+    $crit_data["values"] = str_replace(" ", "",$crit_data["values"]);
 
     # hmm, rather get is some other way, this is a bit unnecessary
     $type = Sql_Fetch_Row_Query("select type from {$tables["attribute"]} where id = ".$crit_data["attribute"]);
-    $operator = "";
+    $operator = $where_clause = $select_clause = "";
     switch($type[0]) {
       case "checkboxgroup":
         $or_clause = '';
@@ -789,7 +801,7 @@ $existing_criteria = '';
 if (sizeof($subqueries)) {
 #    $count_query = "select distinct $select_clause where $where_clause";
 #    $count_query = addslashes($count_query);
-  if ($_GET["calculate"]) {
+  if (!empty($_GET["calculate"])) {
     ob_end_flush();
    # print "<h1>$count_query</h1>";
     print "<p>".$GLOBALS['I18N']->get("calculating")." ...";
@@ -816,8 +828,8 @@ if (sizeof($subqueries)) {
 
   $count_query = sprintf('select * from %s where id in (%s)',$GLOBALS['tables']['user'],join(', ',$userids));
 
-  if ($_GET["calculate"]) {
-    printf('.. '.$GLOBALS['I18N']->get('%d users apply'),$num).'</p>';
+  if (!empty($_GET["calculate"])) {
+    printf('.. '.$GLOBALS['I18N']->get('%d users apply'),$num_users).'</p>';
   }
 
   if ($messageid) {
@@ -1010,9 +1022,10 @@ if (!$done) {
     $formatting_content .= '>';
   }
 
-  $formatting_content .= $GLOBALS['I18N']->get("textandhtml").' <input type=radio name="sendformat" value="text and HTML" ';
-  $formatting_content .= $_POST["sendformat"]=="text and HTML" || !isset($_POST["sendformat"]) ?"checked":"";
-  $formatting_content .= '>';
+//  0009687: Confusing use of the word "Both", indicating one email with both text and html and not two emails
+//  $formatting_content .= $GLOBALS['I18N']->get("textandhtml").' <input type=radio name="sendformat" value="text and HTML" ';
+//  $formatting_content .= $_POST["sendformat"]=="text and HTML" || !isset($_POST["sendformat"]) ?"checked":"";
+//  $formatting_content .= '>';
 
   if (USE_PDF) {
     $formatting_content .= $GLOBALS['I18N']->get("textandpdf").' <input type=radio name="sendformat" value="text and PDF" ';
@@ -1438,7 +1451,7 @@ if (!$done) {
 
   </style>';
   $values_drop .= '<span id="values_span" class="values_span">';
-  $values_drop .= '<input class="criteria_element" name="criteria_values" id="criteria_values_text" size=15 type=text>';
+  $values_drop .= '<input class="criteria_element" name="criteria_values[]" id="criteria_values_text" size=15 type=text>';
 #  $values_drop .= '</span>';
 #  $values_drop .= '<span id="values_select">';
   $values_drop .= '<select class="criteria_element" name="criteria_values[]" id="criteria_values_select" multiple size=10></select>';
