@@ -1,7 +1,7 @@
 <?php
 require_once dirname(__FILE__).'/accesscheck.php';
 
-define("STRUCTUREVERSION","2.10.3");
+define("STRUCTUREVERSION","2.10.5");
 
 $DBstruct = array( # order of tables is essential for smooth upgrade
     "attribute" => array ( # attributes of a user or a message
@@ -104,10 +104,10 @@ $DBstruct = array( # order of tables is essential for smooth upgrade
     ),
     "message" => array ( # a message
         "id" => array("integer not null primary key auto_increment","ID"),
-        "subject" => array("varchar(255) not null","subject"),
-        "fromfield" => array("varchar(255) not null","from"),
-        "tofield" => array("varchar(255) not null","tofield"),
-        "replyto" => array("varchar(255) not null","reply-to"),
+        "subject" => array("varchar(255) not null default '(no subject)'","subject"),
+        "fromfield" => array("varchar(255) not null default ''","from"),
+        "tofield" => array("varchar(255) not null default ''","tofield"),
+        "replyto" => array("varchar(255) not null default ''","reply-to"),
         "message" => array("Text","Message"),
         "textmessage" => array("Text","Text version of Message"),
         "footer" => array("text","Footer for a message"),
@@ -126,7 +126,7 @@ $DBstruct = array( # order of tables is essential for smooth upgrade
         "processed" => array("mediumint unsigned default 0", "Number Processed"),
         "astext" => array("integer default 0","Sent as text"),
         "ashtml" => array("integer default 0","Sent as HTML"),
-        "astextandhtml" => array("integer default 0","Sent as Text and HTML"),
+        "astextandhtml" => array("integer default 0","Sent as Text and HTML"), // obsolete
         "aspdf" => array("integer default 0","Sent as PDF"),
         "astextandpdf" => array("integer default 0","Sent as Text and PDF"),
         "viewed" => array("integer default 0","Was the message viewed"),
