@@ -4,8 +4,10 @@ require_once dirname(__FILE__)."/accesscheck.php";
 mt_srand((double)microtime()*1000000);
 $randval = mt_rand();
 
-if (!$id) {
+if (empty($id) && isset($_GET['id'])) {
   $id = sprintf('%d',$_GET["id"]);
+} elseif (!isset($id)) {
+  $id = 0;
 }
 
 if (!$id && $_GET["page"] != "import1") {
@@ -15,12 +17,13 @@ if (!$id && $_GET["page"] != "import1") {
 require_once dirname(__FILE__)."/date.php";
 $date = new Date();
 
+## Check if input is complete
 $allthere = 1;
 $subscribepagedata = PageData($id);
 if (isset($subscribepagedata['language_file']) && is_file(dirname(__FILE__).'/../texts/'.$subscribepagedata['language_file'])) {
   @include dirname(__FILE__).'/../texts/'.$subscribepagedata['language_file'];
 }
-$required = array();
+$required = array();   # id's of missing attribbutes
 if (sizeof($subscribepagedata)) {
   $attributes = explode('+',$subscribepagedata["attributes"]);
   foreach ($attributes as $attribute) {
@@ -52,7 +55,7 @@ if (sizeof($required)) {
       $thisonemissing = 0;
       if ($row["type"] != "hidden") {
         $thisonemissing = empty($_POST[$fieldname]);
-        if ($thisonemissing && isset($_POST[$fieldname]))
+        if ($thisonemissing)
           $missing .= $row["name"] .", ";
         $allthere = $allthere && !$thisonemissing;
       }
@@ -75,6 +78,20 @@ if (isset($subscribepagedata['emaildoubleentry']) && $subscribepagedata['emaildo
     $missing = $GLOBALS["strEmailsNoMatch"];
   }
 }
+
+// anti spambot check
+if (!empty($_POST['VerificationCodeX'])) {
+  if (NOTIFY_SPAM) {
+    $msg = $GLOBALS['I18N']->get('spamblockemailintro');
+    foreach ($_REQUEST as $key => $val) {
+      $msg .= "\n".'Form field: '.htmlentities($key)."\n".'================='."\nSubmitted value: ".htmlentities($val)."\n".'=============='."\n\n";
+    }
+    sendAdminCopy("phplist Spam blocked","\n".$msg);
+  }
+  unset($msg);
+  return;
+}
+
 if (!isset($_POST['passwordreq'])) $_POST['passwordreq'] = '';
 if (!isset($_POST['password'])) $_POST['password'] = '';
 
@@ -293,7 +310,7 @@ if (isset($_POST["subscribe"]) && is_email($_POST["email"]) && $listsok
 
   $blacklisted = isBlackListed($email);
   if ($blacklisted) {
-    $thankyoupage .= '<p>'.$GLOBALS['I18N']->get('YouAreBlacklisted').'</p>';
+    $thankyoupage .= '<p>'.$GLOBALS["strYouAreBlacklisted"].'</p>';
   }
   if ($sendrequest && $listsok) { #is_array($_POST["list"])) {
     if (sendMail($email, getConfig("subscribesubject:$id"), $subscribemessage,system_messageheaders($email),$envelope,1)) {
@@ -303,7 +320,7 @@ if (isset($_POST["subscribe"]) && is_email($_POST["email"]) && $listsok
      } else {
       print '<h3>'.$strEmailFailed.'</h3>';
       if ($blacklisted) {
-        print '<p>'.$GLOBALS['I18N']->get('YouAreBlacklisted').'</p>';
+        print '<p>'.$GLOBALS["strYouAreBlacklisted"].'</p>';
       }
     }
   } else {
@@ -482,7 +499,7 @@ if (isset($_POST["subscribe"]) && is_email($_POST["email"]) && $listsok
         Sql_query(sprintf('replace into %s (attributeid,userid,value) values("%s","%s","%s")',
           $GLOBALS["tables"]["user_attribute"],$attribute["id"],$userid,$value));
         if ($attribute["type"] != "hidden") {
-          $datachange .= strip_tags($attribute["name"]) . " = ";
+          $datachange .= strip_tags($attribute["name"]) . " : ";
           if ($attribute["type"] == "checkbox")
             $datachange .= $value?$strYes:$strNo;
           elseif ($attribute["type"] != "date" && $attribute["type"] != "textline" && $attribute["type"] != "textarea")
@@ -561,10 +578,10 @@ if (isset($_POST["subscribe"]) && is_email($_POST["email"]) && $listsok
   $msg = '<div class="missing">'.$strEnterEmail.'</div><br/>';
 } elseif ((isset($_POST["subscribe"]) || isset($_POST["update"])) && !$validhost) {
   $msg = '<div class="missing">'.$strInvalidHostInEmail.'</div><br/>';
-} elseif ((isset($_POST["subscribe"]) || isset($_POST["update"])) && !isset($_POST["list"]) && !ALLOW_NON_LIST_SUBSCRIBE) {
-  $msg = '<div class="missing">'.$strEnterList.'</div><br/>';
 } elseif ((isset($_POST["subscribe"]) || isset($_POST["update"])) && $missing) {
   $msg = '<div class="missing">'."$strValuesMissing: $missing".'</div><br/>';
+} elseif ((isset($_POST["subscribe"]) || isset($_POST["update"])) && !isset($_POST["list"]) && !ALLOW_NON_LIST_SUBSCRIBE) {
+  $msg = '<div class="missing">'.$strEnterList.'</div><br/>';
 } else {
 #  $msg = 'Unknown Error';
 }
@@ -666,6 +683,7 @@ function ListAttributes($attributes,$attributedata,$htmlchoice = 0,$userid = 0,$
   if (!$textarearows) $textarearows = 10;
   if (!$textareacols) $textareacols = 40;
 
+  $html = '';
   if (!isset($_GET['page']) || (isset($_GET['page']) && $_GET["page"] != "import1"))
   $html = sprintf('
   <tr><td><div class="required">%s</div></td>
@@ -681,7 +699,7 @@ $html .= sprintf('
   <tr><td><div class="required">%s</div></td>
   <td class="attributeinput"><input type=text name=emailconfirm value="%s" size="%d">
   <script language="Javascript" type="text/javascript">addFieldToCheck("emailconfirm","%s");</script></td></tr>',
- $GLOBALS["strConfirmEmail"],htmlspecialchars(stripslashes($_REQUEST["emailconfirm"])),$textlinewidth,'Confirm email');
+  $GLOBALS["strConfirmEmail"],htmlspecialchars(stripslashes($_REQUEST["emailconfirm"])),$textlinewidth, $GLOBALS["$strConfirmEmail"]);
 }
 // BPM 12 May 2004 - Finish
 
@@ -709,6 +727,7 @@ $html .= sprintf('
   $pwdclass,$GLOBALS["strPassword2"],$textlinewidth,$js2);
    }
 
+## Write attribute fields
   switch($htmlchoice) {
     case "textonly":
       if (!isset($htmlemail))
@@ -797,12 +816,14 @@ $html .= sprintf('
             $checked = $data[$attr["id"]] ? "checked":"";
           $output[$attr["id"]] .= sprintf("\n".'<input type="checkbox" name="%s" value="on" %s class="attributeinput">',$fieldname,$checked);
           $output[$attr["id"]] .= sprintf("\n".'<span class="%s">%s</span>',$attr["required"] ? 'required' : 'attributename',stripslashes($attr["name"]));
+          if ($attr["required"])
+            $output[$attr["id"]] .= sprintf('<script language="Javascript" type="text/javascript">addFieldToCheck("%s","%s");</script>',$fieldname,$attr["name"]);
           break;
         case "radio":
           $output[$attr["id"]] .= sprintf("\n".'<tr><td colspan=2><div class="%s">%s</div>',$attr["required"] ? 'required' : 'attributename',stripslashes($attr["name"]));
           $values_request = Sql_Query("select * from $table_prefix"."listattr_".$attr["tablename"]." order by listorder,name");
           while ($value = Sql_Fetch_array($values_request)) {
-            if ($_POST[$fieldname])
+            if (!empty($_POST[$fieldname]))
               $checked = $_POST[$fieldname] == $value["id"] ? "checked":"";
             else if ($data[$attr["id"]])
               $checked = $data[$attr["id"]] == $value["id"] ? "checked":"";
@@ -811,13 +832,15 @@ $html .= sprintf('
             $output[$attr["id"]] .= sprintf('&nbsp;%s&nbsp;<input type=radio  class="attributeinput" name="%s" value="%s" %s>',
               $value["name"],$fieldname,$value["id"],$checked);
           }
+          if ($attr["required"])
+            $output[$attr["id"]] .= sprintf('<script language="Javascript" type="text/javascript">addGroupToCheck("%s","%s");</script>',$fieldname,$attr["name"]);
           break;
         case "select":
           $output[$attr["id"]] .= sprintf("\n".'<tr><td><div class="%s">%s</div>',$attr["required"] ? 'required' : 'attributename',stripslashes($attr["name"]));
           $values_request = Sql_Query("select * from $table_prefix"."listattr_".$attr["tablename"]." order by listorder,name");
           $output[$attr["id"]] .= sprintf('</td><td class="attributeinput"><!--%d--><select name="%s" class="attributeinput">',$data[$attr["id"]],$fieldname);
           while ($value = Sql_Fetch_array($values_request)) {
-            if ($_POST[$fieldname])
+            if (!empty($_POST[$fieldname]))
               $selected = $_POST[$fieldname] == $value["id"] ? "selected" : "";
             else if ($data[$attr["id"]])
               $selected = $data[$attr["id"]] == $value["id"] ? "selected":"";
