@@ -68,6 +68,10 @@ if (isset($_GET['id'])) {
 } else {
   $id = 0;
 }
+// What is id,
+// What is uid
+// What is userid
+// Why is there GET(id) and REQUEST(id)?
 
 if (isset($_GET['uid']) && $_GET["uid"]) {
   $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where uniqid = "%s"',
@@ -139,6 +143,8 @@ $login_required =
 if ($login_required && empty($_SESSION["userloggedin"])) {
   $canlogin = 0;
   if (!empty($_POST["login"])) {
+    # login button pushed, let's check formdata
+    
     if (empty($_POST["email"])) {
       $msg = $strEnterEmail;
     } elseif (empty($_POST["password"])) {
@@ -157,6 +163,7 @@ if ($login_required && empty($_SESSION["userloggedin"])) {
       $_SESSION["userloggedin"] = $_SERVER["REMOTE_ADDR"];
      }
    } elseif (!empty($_POST["forgotpassword"])) {
+    # forgot password button pushed
     if (!empty($_POST["email"]) && $_POST["email"] == $emailcheck) {
       sendMail ($emailcheck,$GLOBALS["strPasswordRemindSubject"],$GLOBALS["strPasswordRemindMessage"]." ".$userpassword,system_messageheaders());
       $msg = $GLOBALS["strPasswordSent"];
@@ -164,10 +171,12 @@ if ($login_required && empty($_SESSION["userloggedin"])) {
       $msg = $strPasswordRemindInfo;
     }
   } elseif (isset($_SESSION["userdata"]["email"]["value"]) && $_SESSION["userdata"]["email"]["value"] == $emailcheck) {
+    # Entry without any button pushed (first time) test and, if needed, ask for password
     $canlogin = $_SESSION["userloggedin"];
     $msg = $strEnterPassword;
   }
 } else {
+  # Logged into session or login not required 
   $canlogin = 1;
 }
 
@@ -401,18 +410,30 @@ function subscribePage($id) {
 
 <script language="Javascript" type="text/javascript">
 
-var fieldstocheck = new Array();
-    fieldnames = new Array();
-
 function checkform() {
   for (i=0;i<fieldstocheck.length;i++) {
-    if (eval("document.subscribeform.elements[\'"+fieldstocheck[i]+"\'].value") == "") {
-      alert("'.$GLOBALS["strPleaseEnter"].' "+fieldnames[i]);
-      eval("document.subscribeform.elements[\'"+fieldstocheck[i]+"\'].focus()");
+    if (eval("document.subscribeform.elements[\'"+fieldstocheck[i]+"\'].type") == "checkbox") {
+      if (document.subscribeform.elements[fieldstocheck[i]].checked) {
+      } else {
+        alert("'.$GLOBALS["strPleaseEnter"].' "+fieldnames[i]);
+        eval("document.subscribeform.elements[\'"+fieldstocheck[i]+"\'].focus()");
+        return false;
+      }
+    }
+    else {
+      if (eval("document.subscribeform.elements[\'"+fieldstocheck[i]+"\'].value") == "") {
+        alert("'.$GLOBALS["strPleaseEnter"].' "+fieldnames[i]);
+        eval("document.subscribeform.elements[\'"+fieldstocheck[i]+"\'].focus()");
+        return false;
+      }
+    }
+  }
+  for (i=0;i<groupstocheck.length;i++) {
+    if (!checkGroup(groupstocheck[i],groupnames[i])) {
       return false;
     }
   }
-';
+  ';
 if ($data['emaildoubleentry']=='yes')
 {
 $html .='
@@ -427,16 +448,36 @@ $html .='
   return true;
 }
 
-
+var fieldstocheck = new Array();
+var fieldnames = new Array();
 function addFieldToCheck(value,name) {
   fieldstocheck[fieldstocheck.length] = value;
   fieldnames[fieldnames.length] = name;
 }
+var groupstocheck = new Array();
+var groupnames = new Array();
+function addGroupToCheck(value,name) {
+  groupstocheck[groupstocheck.length] = value;
+  groupnames[groupnames.length] = name;
+}
 
 function compareEmail()
 {
   return (document.subscribeform.elements["email"].value == document.subscribeform.elements["emailconfirm"].value);
 }
+function checkGroup(name,value) {
+  option = -1;
+  for (i=0;i<document.subscribeform.elements[name].length;i++) {
+    if (document.subscribeform.elements[name][i].checked) {
+      option = i;
+    }
+  }
+  if (option == -1) {
+    alert ("'.$GLOBALS["strPleaseEnter"].' "+value);
+    return false;
+  }
+  return true;
+}
 
 </script>';
   $html .= formStart('name="subscribeform"');
@@ -466,9 +507,11 @@ function compareEmail()
    }
   $html .= ListAvailableLists("",$data["lists"]);
 
-  if (!empty($data['button'])) {
+  if (empty($data['button'])) {
     $data['button'] = $GLOBALS['strSubmit'];
   }
+  if (USE_SPAM_BLOCK)
+    $html .= '<div style="display:none"><input type="text" name="VerificationCodeX" value="" size="20"></div>';
   $html .= '<p><input type=submit name="subscribe" value="'.$data["button"].'" onClick="return checkform();"></p>
     </form><br/><br/>
     <p><a href="'.getConfig("unsubscribeurl").'&id='.$id.'">'.$GLOBALS["strUnsubscribe"].'</a></p>
@@ -544,8 +587,8 @@ function unsubscribePage($id) {
     @include dirname(__FILE__).'/texts/'.$pagedata['language_file'];
   }
   global $tables;
-  $res = $pagedata["header"];
   $res .= '<title>'.$GLOBALS["strUnsubscribeTitle"].'</title>';
+  $res = $pagedata["header"];
   if (isset($_GET["uid"])) {
     $req = Sql_Query("select * from $tables[user] where uniqid = \"".$_GET["uid"]."\"");
     $userdata = Sql_Fetch_Array($req);
